Introduction
============

collective.pygal.core integrates the pygal dynamic SVG charting library
into Plone. On its own this package does not provide any functionality,
it just registers the CSS and Javascript pygal requires.

In the future common fuctionalities that make pygal easier to use in
plone will be integrated here.


What is pygal?
==============

Pygal is a python SVG Charts Creator. To produce good looking charts
you do not need any bulky javascript libraries, the svg creation
is entirely done in python on the serverside with only a minimum
of javascript embedded to create some effects. Pygal is easy to use
and provides flexible and customizable layouts.


It features various graph types:

- Bar charts

- Line charts

- XY charts

- Pie charts

- Radar charts

Python/Css styling with some packaged themes (default, light, neon,
clean, dark_solarized, light_solarized)
And a lot of options to customize the charts.


See http://pygal.org/ for more information.

pygal requires 2.6 > python > 3.0
